@@ -1248,6 +1248,17 @@ class OraDownloadData:
         logger.info("[%s] Loaded student identifiers (len=%d)", course_id, len(student_identifiers_map))
 
         for student, submission, _ in all_submission_information:
+            # Submissions created from the studio authoring view will create a submission for
+            # a student called `student` with no mapping to a real django User. Doing so should no longer be allowed,
+            # but this remains for backwards compatibility.
+            if student['student_id'] not in student_identifiers_map:
+                logger.info(
+                    "[%s] Student id %s has no mapping to a user and will be skipped",
+                    course_id,
+                    student['student_id']
+                )
+                continue
+
             logger.info(
                 "[%s] Collecting files for %s, submission %s ",
                 course_id,
